@@ -1,7 +1,8 @@
-from grok import name, context, require
+from grokcore.component import name, context
+from grokcore.security import require
 
 from dolmen.content.interfaces import *
-from dolmen.content.directives import schema, icon, factory, nofactory
+from dolmen.content.directives import schema, factory, nofactory
 from dolmen.content.factoring import Factory
 from dolmen.content.base import BaseContent, Content
 from dolmen.content.base import Container, OrderedContainer
