@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
 
-import martian
-
-from directives import schema
-from interfaces import IFactory
+from dolmen.content.directives import schema
+from dolmen.content.interfaces import IFactory
 from zope.i18nmessageid import MessageFactory
 from zope.schema.fieldproperty import FieldProperty
 from zope.interface import implements, implementedBy
@@ -25,11 +23,11 @@ class Factory(object):
 
     def getSchema(self):
         return schema.bind().get(self.factory)
-        
+
     @property
     def title(self):
         return _(u"add_action", default=u"Add: ${name}",
-                 mapping = {'name': self.factory.__content_type__})
-                                   
+                 mapping={'name': self.factory.__content_type__})
+
     def __call__(self, *args, **kw):
         return self.factory(*args, **kw)
